==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/CadToolBar/ts/CadToolBar_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>CadToolBar</name>
    <message>
        <location filename="../CadToolBar.js" line="+49"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>CAD Toolbar</source>
        <translation>Barre d&apos;outils de CAO</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Toggle Title Bar</source>
        <translation>Montrer la barre de titre</translation>
    </message>
    <message>
        <source>CAD Tool Bar</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Barre d&apos;outils de CAO</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Icon Size:</source>
        <translation>Taille des icônes :</translation>
    </message>
    <message>
        <location line="+71"/>
        <source>Pixel</source>
        <translatorcomment>--google--
Portable Pixel Map
X Pixel Map
Pixels par unité de dessin :</translatorcomment>
        <translation>Pixel</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>px</source>
        <translatorcomment>--google--
Espacement de grille minimal (px) :
Espacement de grille minimal (px)</translatorcomment>
        <translation>px</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Columns:</source>
        <translation>Colonnes :</translation>
    </message>
</context>
<context>
    <name>CadToolBarPanel</name>
    <message>
        <location filename="../CadToolBarPanel.js" line="+76"/>
        <source>Back</source>
        <translation>Précédent</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/CadToolBar/ts/CadToolBar_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>CadToolBar</name>
    <message>
        <location filename="../CadToolBar.js" line="+51"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>CAD Toolbar</source>
        <translation>Barre d&apos;outils de CAO</translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Vertical/Horizontal</source>
        <translation>Vertical / Horizontal</translation>
    </message>
    <message>
        <source>Toggle Title Bar</source>
        <translation type="vanished">Montrer la barre de titre</translation>
    </message>
    <message>
        <source>CAD Tool Bar</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Barre d&apos;outils de CAO</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Icon Size:</source>
        <translation>Taille des icônes :</translation>
    </message>
    <message>
        <location line="+71"/>
        <source>Pixel</source>
        <translatorcomment>--google--
Portable Pixel Map
X Pixel Map
Pixels par unité de dessin :</translatorcomment>
        <translation>Pixel</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>px</source>
        <translatorcomment>--google--
Espacement de grille minimal (px) :
Espacement de grille minimal (px)</translatorcomment>
        <translation>px</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Columns:</source>
        <translation>Colonnes :</translation>
    </message>
</context>
<context>
    <name>CadToolBarPanel</name>
    <message>
        <location filename="../CadToolBarPanel.js" line="+107"/>
        <source>Back</source>
        <translation>Précédent</translation>
    </message>
</context>
</TS>
